@@ -1,6 +1,7 @@
 
 
-PLS_pheno <- function (weather_data,bio_data,split_month=7,runn_mean=11,expl.var=30,ncomp.fix=NULL,use_Tmean=FALSE,return.all=FALSE,crossvalidate="none") {
+PLS_pheno <- function (weather_data,bio_data,split_month=7,runn_mean=11,expl.var=30,
+                       ncomp.fix=NULL,use_Tmean=FALSE,return.all=FALSE,crossvalidate="none",end_at_pheno_end=TRUE) {
 
   # Interpolate missing temperatures and calculate Tmean from Tmin and Tmax - NEW: only if necessary
     if (!use_Tmean) { 
@@ -59,17 +60,58 @@ PLS_pheno <- function (weather_data,bio_data,split_month=7,runn_mean=11,expl.var
         if (nrow(yearweather) == 365) {
             labdates <- yearweather$Date
             labJdates <- yearweather$JDay  }  }
-    colnames(year_res) <- paste("runn_", 1:365, sep="")
-    data_set <- cbind(Season=seasons, year_res)
-    data_set <- data_set[which(!is.na(rowMeans(data_set))), ]  # Only seasons with temperatures from first to last day
-    newseasons <- data_set[, "Season"]  # vector with full seasons
     
-    # Reduce phenological data to those of full seasons; Reduce both datasets to those with phenology data
-    bio_data <- bio_data[!is.na(bio_data$pheno), ]
-    bio_data <- subset(bio_data,bio_data$Year %in% newseasons)
-    bio <- as.numeric(as.character(bio_data$pheno))
-    indep <- data_set[data_set[,"Season"] %in% bio_data$Year, ]
-    indep <- indep[,-1]
+    
+    
+    colnames(year_res) <- paste("runn_", 1:365, sep="")
+    year_res <- cbind(Season = seasons, year_res)
+    data_set <- year_res
+    full_seasons <- which(!is.na(rowMeans(data_set)))
+    data_set <- data_set[full_seasons, ]
+    newseasons <- data_set[, "Season"]
+    suppressWarnings(bio_data <- bio_data[which(bio_data[, 
+                                                         "Year"] %in% newseasons), ])
+    suppressWarnings(bio_data <- bio_data[which(!is.na(as.numeric(as.character(bio_data$pheno)))), 
+                                          ])
+    #all_outputs[["pheno"]]<-bio_data
+    suppressWarnings(bio <- as.numeric(as.character(bio_data$pheno)))
+    indep <- as.matrix(data_set[which(data_set[, "Season"] %in% 
+                                        bio_data$Year), ])
+    indep <- indep[, 2:ncol(indep)]
+    
+    pheno_end<-get_last_date(as.numeric(as.character(bio_data$pheno)))
+    
+    if(is.numeric(end_at_pheno_end)) pheno_end<-end_at_pheno_end
+    
+    if(end_at_pheno_end) if (pheno_end %in% labJdates) {dayskeep<-1:which(labJdates==pheno_end)
+    labJdates<-labJdates[dayskeep]
+    labdates<-labdates[dayskeep]
+    
+    indep<-indep[,dayskeep]}
+    
+    
+    
+   # colnames(year_res) <- paste("runn_", 1:365, sep="")
+  #  data_set <- cbind(Season=seasons, year_res)
+  #  data_set <- data_set[which(!is.na(rowMeans(data_set))), ]  # Only seasons with temperatures from first to last day
+  #  newseasons <- data_set[, "Season"]  # vector with full seasons
+    
+  #  # Reduce phenological data to those of full seasons; Reduce both datasets to those with phenology data
+  #  bio_data <- bio_data[!is.na(bio_data$pheno), ]
+  #  bio_data <- subset(bio_data,bio_data$Year %in% newseasons)
+  #  bio <- as.numeric(as.character(bio_data$pheno))
+  #  indep <- data_set[data_set[,"Season"] %in% bio_data$Year, ]
+  #  indep <- indep[,-1]
+    
+  #  pheno_end<-max(as.numeric(as.character(bio_data$pheno)),na.rm=TRUE)
+    
+  #  if(is.numeric(end_at_pheno_end)) pheno_end<-end_at_pheno_end
+  #  
+  #  if(end_at_pheno_end) if (pheno_end %in% labJdates) {dayskeep<-1:which(labJdates==pheno_end)
+  #  labJdates<-labJdates[dayskeep]
+  #  labdates<-labdates[dayskeep]
+  #  
+  #  indep<-indep[,dayskeep]}
     
     if (is.null(ncomp.fix)) {ncomp <- pls_ncomp(indep=indep,dep=bio,threshold=expl.var) } else {ncomp <- ncomp.fix}   ### NEW, works with fixed ncomp
    
@@ -81,10 +123,12 @@ PLS_pheno <- function (weather_data,bio_data,split_month=7,runn_mean=11,expl.var
     d1 <- switch(split_month,31,59,89,120,151,181,212,243,274,304,335,365)
 	labJdates[labJdates>d1] <- labJdates[labJdates>d1]-365
     out <- data.frame()
-    out[1:365,"Date"] <- labdates
-    out[1:365,"JDay"] <- labJdates
-    out[1:365,"Coef"] <- coef(PLS_output)
-    out[1:365,"VIP"] <- VIP(PLS_output)[ncomp, ]
-    out[1:365,"Tmean"] <- colMeans(indep)
-    out[1:365,"Tstdev"] <- apply(indep, 2, sd, na.rm = TRUE)
-    if (return.all) return(list(object_type="PLS_Temp_pheno",PLS_summary=out,PLS_output=PLS_output)) else return(list(object_type="PLS_Temp_pheno",PLS_summary=out))  }
+    tablength<-length(coef(PLS_output))
+    out[1:tablength,"Date"] <- labdates
+    out[1:tablength,"JDay"] <- labJdates
+    out[1:tablength,"Coef"] <- coef(PLS_output)
+    out[1:tablength,"VIP"] <- VIP(PLS_output)[ncomp, ]
+    out[1:tablength,"Tmean"] <- colMeans(indep)
+    out[1:tablength,"Tstdev"] <- apply(indep, 2, sd, na.rm = TRUE)
+    if (return.all) return(list(object_type="PLS_Temp_pheno",pheno=bio_data,PLS_summary=out,PLS_output=PLS_output)) else return(list(object_type="PLS_Temp_pheno",pheno=bio_data,PLS_summary=out))  }
+
